Detects change points in animal movement trajectory data using a permutation-based approach.
This function identifies locations where the movement pattern significantly changes.
change_point_fit_pvalue(bx, by, q_max, n)
Arguments
- bx
a numeric vector of x-coordinates of the trajectory backwards in time.
- by
a numeric vector of y-coordinates of the trajectory backwards in time.
- q_max
q_max maximum number of q to be tested
- n
an integer specifying the number of random permutations for the permutation test.