summary.change_point_test.RdExtracts and summarizes change points detected by the change_point_test function.
This function processes the output from change_point_test to create a data frame
containing the temporal and spatial information for each identified change point.
# S3 method for class 'change_point_test'
summary(object, ...)an object of class change_point_test or
change_point_test_list containing movement data with change point information,
typically the output from change_point_test(). Must contain columns x and y coordinates,
a timestamp, and 'cp_id'.
other arguments passed to summary
A data frame with one row per change point and the following columns:
Timestamp of the first observation in the change point segment
Timestamp of the last observation in the change point segment
X-coordinate (northing) of the change point location
Y-coordinate (easting) of the change point location
library("cpt")
# First detect change points
cpt <- change_point_test(cpttestdata, alpha = 0.05, q = 3, n = 500)
# Then extract the change points into a summarized format
summary(cpt)
#> first last east north id
#> track_1.1 2025-01-01 00:38:00 2025-01-01 00:38:00 588443.2 703275.0 track_1
#> track_1.2 2025-01-01 00:54:00 2025-01-01 00:54:00 587898.1 703728.7 track_1